Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CLI ¶
type CLI struct {
basecli.BaseCLI `embed:""`
Project1 Project1Cmd `cmd:"" help:"Execute project1 grading client"`
Project2 Project2Cmd `cmd:"" help:"Execute project2 grading client"`
Project3 Project3Cmd `cmd:"" help:"Execute project3 grading client"`
}
CLI defines the command-line interface structure for the gradebot application.
type CodeDirArg ¶
type CodeDirArg struct {
CodeDir string `default:"." help:"Path to the source code directory" name:"code-dir"`
}
type CommonProjectArgs ¶
type CommonProjectArgs struct {
PortArg `embed:""`
CodeDirArg `embed:""`
DBFileCodeArg `embed:""`
}
type DBFileCodeArg ¶
type DBFileCodeArg struct {
DatabaseFile string `default:"totally_not_my_privateKeys.db" help:"Path to the database file" name:"database"`
}
type PortArg ¶
type PortArg struct {
Port int `default:"8080" help:"Port to check" name:"port" short:"p"`
}
type Project1Cmd ¶
type Project1Cmd struct {
basecli.CommonArgs `embed:""`
PortArg `embed:""`
}
Project1Cmd defines the command structure for running Project 1 grading.
type Project2Cmd ¶
type Project2Cmd struct {
basecli.CommonArgs `embed:""`
CommonProjectArgs `embed:""`
}
Project2Cmd defines the command structure for running Project 2 grading.
type Project3Cmd ¶
type Project3Cmd struct {
basecli.CommonArgs `embed:""`
CommonProjectArgs `embed:""`
}
Project3Cmd defines the command structure for running Project 3 grading.
Click to show internal directories.
Click to hide internal directories.